@@ -546,11 +546,6 @@ class LabApp(NBClassicConfigShimMixin, LabServerApp):
     expose_app_in_browser = Bool(False, config=True,
         help="Whether to expose the global app instance to browser via window.jupyterlab")
 
-    # By default, open a browser for JupyterLab
-    serverapp_config = {
-        "open_browser": True
-    }
-
     @default('app_dir')
     def _default_app_dir(self):
         app_dir = get_app_dir()
@@ -730,6 +725,10 @@ class LabApp(NBClassicConfigShimMixin, LabServerApp):
         self.handlers.extend(handlers)
         super().initialize_handlers()
 
+    def initialize(self, argv=None):
+        """Subclass because the ExtensionApp.initialize() method does not take arguments"""
+        super().initialize()
+
 #-----------------------------------------------------------------------------
 # Main entry point
 #-----------------------------------------------------------------------------
